@@ -1,9 +1,10 @@
-from nanograd.tensor import Tensor
-from nanograd.device import Device
-import nanograd.nn.functional as F
-
 import numpy as np
 
+from nanograd.tensor import Tensor
+import nanograd.tensor as tensor
+
+from nanograd.device import Device
+
 from typing import Union
 
 
@@ -628,7 +629,7 @@ class CrossEntropyLoss(Module):
            Returns:
                 Tensor: loss, stored as a float in a tensor 
         """
-        return F.cross_entropy(predicted, target)
+        return tensor.cross_entropy(predicted, target)
     
 
 class MSELoss(Module):
